#include <iostream>
#include <iomanip>
#include <vector>

#include <algorithm>

using namespace std;

typedef long long ll;
typedef long double ld;

constexpr ll INF = 1e17;

const pair<ll, ll> mnx(const pair<ll, ll>& a, const pair<ll, ll>& b) {
	return make_pair(min(a.first, b.first), max(a.second, b.second));
}

class SegTree {
private:
	// min, max
	vector<pair<ll, ll>> v;
	size_t size = 0;

public:
	SegTree() = default;

	SegTree(const size_t sz) {
		for (size = 1; size < sz; size *= 2);
		v.resize(size * 2, make_pair(INF, -INF));
	}

	SegTree(const vector<ll>& a) {
		for (size = 1; size < a.size(); size *= 2);
		v.resize(size * 2, make_pair(INF, -INF));

		for (size_t i = 0; i < a.size(); ++i) {
			v[size + i] = make_pair(a[i], a[i]);
		}
		for (size_t i = size - 1; i > 0; --i) {
			v[i] = mnx(v[i * 2], v[i * 2 + 1]);
		}
	}

	const pair<ll, ll> operator()(ll first, ll last) const {
		first += size;
		last += size;
		pair<ll, ll> res = make_pair(INF, -INF);
		for (; first < last; first /= 2, last /= 2) {
			if (first % 2)
				res = mnx(res, v[first++]);
			if (last % 2)
				res = mnx(res, v[--last]);
		}
		return res;
	}
};

vector<ll> a;
ll n;

ll res = INF;

void solve() {
	vector<ll> sm1(n / 2), sm2(n / 2 + 1);

	for (ll i = 0; i < n / 2; ++i) {
		sm1[i] = a[i] + a[n - i - 1];
	}
	for (ll i = 1; i <= n / 2; ++i) {
		sm2[i] = a[i] + a[n - i];
	}

	SegTree st1(sm1);
	SegTree st2(sm2);

	pair<ll, ll> buf = make_pair(INF, -INF);
	for (ll j = 0; j <= n / 2; ++j) {
		buf = mnx(buf, st1(0, j));
		buf = mnx(buf, st2(j + 1, n / 2 + 1));

		if (buf.second - buf.first < res) {
			res = buf.second - buf.first;
		}
	}
}

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);
	cout.tie(nullptr);

	cin >> n;
	a.resize(n);
	for (auto& t : a)
		cin >> t;
	sort(a.begin(), a.end());
	solve();

	reverse(a.begin(), a.end());
	solve();

	cout << res << '\n';
}