#include <iostream>
#include <iomanip>
#include <vector>

#include <algorithm>

using namespace std;

typedef long long ll;
typedef long double ld;

constexpr ll INF = 1e12;

const pair<ll, ll> mnx(const pair<ll, ll>& a, const pair<ll, ll>& b) {
	return make_pair(min(a.first, b.first), max(a.second, b.second));
}

class SegTree {
private:
	vector<ll> v;
	size_t size = 0;
	vector<ll>& x;

	const ll fn(ll a, ll b) const {
		if (a == INF)
			return b;
		if (b == INF)
			return a;
		return x[a] < x[b] ? a : b;
	}

public:

	SegTree(const size_t sz, vector<ll>& x) : x(x) {
		for (size = 1; size < sz; size *= 2);
		v.resize(size * 2, INF);

		for (size_t i = 0; i < sz; ++i) {
			v[size + i] = i;
		}
		for (size_t i = size - 1; i > 0; --i) {
			v[i] = fn(v[i * 2], v[i * 2 + 1]);
		}
	}

	const ll operator()(ll first, ll last) const {
		first += size;
		last += size;
		ll res = INF;
		for (; first < last; first /= 2, last /= 2) {
			if (first % 2)
				res = fn(res, v[first++]);
			if (last % 2)
				res = fn(res, v[--last]);
		}
		return res;
	}
};


int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);
	cout.tie(nullptr);

	ll n, B, C;
	cin >> n >> B >> C;
	vector<ll> x(n), p(n);
	for (ll i = 0; i < n; ++i) {
		cin >> x[i] >> p[i];
	}
	x.push_back(INF);
	p.push_back(-INF);
	++n;

	vector<ll> right(n, INF);
	vector<ll> stack;
	for (ll i = 0; i < n; ++i) {
		while (!stack.empty() && p[i] < p[stack.back()]) {
			right[stack.back()] = i;
			stack.pop_back();
		}
		stack.push_back(i);
	}

	SegTree st(x.size(), x);

	ll i = 0;
	ll step = 0;

	while (1) {
		if (x[i] + step + min(C - step, B / p[i]) >= x[right[i]]) {
			step -= x[right[i]] - x[i];
			if (step < 0) {
				B += step * p[i];
				step = 0;
			}

			i = right[i];
		}
		else {
			ll max_x = x[i] + step + min(C - step, B / p[i]);
			ll last = upper_bound(x.begin() + i, x.end(), max_x) - x.begin();

			if (last - 1 == i) {
				cout << max_x << '\n';
				return 0;
			}

			ll j = st(i + 1, last);

			ll buf = min(C - step, B / p[i]);
			step = step + buf - (x[j] - x[i]);
			B -= buf * p[i];
			i = j;
		}
	}
}